/**
 * @file
 * VuoCompilerCable implementation.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code is proprietary, and may not be redistributed.
 * For more information, see http://vuo.org/license.
 */

#include <sstream>

#include "VuoCompilerCable.hh"
#include "VuoCompilerTriggerPort.hh"
#include "VuoCompilerOutputEventPort.hh"
#include "VuoPort.hh"

/**
 * Creates a cable from @c fromNode's @c fromPort to @c toNode's @c toPort.
 */
VuoCompilerCable::VuoCompilerCable(VuoCompilerNode * fromNode, VuoCompilerPort * fromPort, VuoCompilerNode * toNode, VuoCompilerPort * toPort)
	: VuoBaseDetail<VuoCable>("VuoCompilerCable",
								new VuoCable(	fromNode? fromNode->getBase() : NULL,
												fromPort? fromPort->getBase() : NULL,
												toNode? toNode->getBase() : NULL,
												toPort? toPort->getBase() : NULL))
{
		getBase()->setCompiler(this);
}

/**
 * Returns a string containing the declaration for this cable
 * as it would appear in a .vuo (Graphviz dot format) file.
 */
string VuoCompilerCable::getGraphvizDeclaration(void)
{
	ostringstream declaration;

	VuoNode *fromNode = getBase()->getFromNode();
	VuoPort *fromPort = getBase()->getFromPort();
	VuoNode *toNode = getBase()->getToNode();
	VuoPort *toPort = getBase()->getToPort();

	if (fromNode && fromPort && toNode && toPort)
	{
		declaration << fromNode->getCompiler()->getGraphvizIdentifier() << ":" << fromPort->getClass()->getName() << " -> "
					<< toNode->getCompiler()->getGraphvizIdentifier() << ":" << toPort->getClass()->getName() << ";";
	}

	return declaration.str();
}
