TEMPLATE = lib
CONFIG += no_link target_predeps staticlib

# Avoid building libdocumentation.a
QMAKE_AR_CMD = @true
QMAKE_RANLIB = @true

include(../vuo.pri)

doxygen.commands = (cat Doxyfile ; echo "PROJECT_NUMBER=$$VUO_VERSION" ; echo "STRIP_FROM_PATH=`(cd .. ; pwd)`") | /usr/local/bin/doxygen -
doxygen.depends = \
	../base/*.c* ../base/*.h* \
	../compiler/*.c* ../compiler/*.h* \
	../editor/*.c* ../editor/*.h* \
	../node/*.c* ../node/*.h* \
	../renderer/*.c* ../renderer/*.h* \
	../type/*.c* ../type/*.h* \
	../type/list/*.c* ../type/list/*.h*
doxygen.target = ../doxygen
QMAKE_EXTRA_TARGETS += doxygen
POST_TARGETDEPS += ../doxygen
QMAKE_CLEAN += ../doxygen
OTHER_FILES += Doxyfile

NODE_CLASS_IMAGES += \
	../node/vuo.console.window.c \
	../node/vuo.device.mouse.c \
	../node/vuo.event.spinOffEvent.c \
	../node/vuo.event.fireOnStart.c \
	../node/vuo.hold.integer.c \
	../node/vuo.image.get.c \
	../node/vuo.math.add.integer.c \
	../node/vuo.math.count.integer.c \
	../node/vuo.select.in.integer.c \
	../node/vuo.select.out.integer.c \
	../node/vuo.time.firePeriodically.c

GRAPH_IMAGES += \
	graph/2Recur.vuo \
	graph/CountCharactersToConsole.vuo \
	graph/CountScatter.vuo \
	graph/DiscardDataFromEventToCount.vuo \
	graph/FeedbackCountWithoutHold.vuo \
	graph/SumAddOne.vuo \
	../example/graph/Count.vuo \
	../example/graph/CountAndHold.vuo \
	../example/graph/CountAndOffset.vuo \
	../example/graph/CountSometimes.vuo \
	../example/graph/FeedbackCount.vuo \
	../example/graph/LoadImageAsynchronously.vuo \
	../example/graph/SMSLength.vuo

pandoc.commands = cat VuoManual.txt \
	| awk \'{sub(/VUO_VERSION/,\"$$VUO_VERSION\");print}\' \
	| /usr/local/bin/pandoc \
	--latex-engine=/usr/texbin/pdflatex \
	--table-of-contents \
	--number-sections \
	--smart \
	--include-in-header=VuoManualHeader.tex \
	--from=markdown \
	-o VuoManual.pdf \
	-
pandoc.depends = VuoManual.txt
NODE_CLASS_IMAGE_BASENAMES = $$basename(NODE_CLASS_IMAGES)
for(i,NODE_CLASS_IMAGE_BASENAMES): pandoc.depends += image-generated/$$replace(i,".c$",".pdf")
GRAPH_IMAGE_BASENAMES = $$basename(GRAPH_IMAGES)
for(i,GRAPH_IMAGE_BASENAMES): pandoc.depends += image-generated/$$replace(i,".vuo$",".pdf")
pandoc.target = VuoManual.pdf
QMAKE_EXTRA_TARGETS += pandoc
POST_TARGETDEPS += VuoManual.pdf
QMAKE_CLEAN += VuoManual.pdf
OTHER_FILES += VuoManual.txt
OTHER_FILES += VuoManualHeader.tex

node_class_image.input = NODE_CLASS_IMAGES
node_class_image.output = image-generated/${QMAKE_FILE_IN_BASE}.pdf
node_class_image.commands  = $$VUORENDER --output-format=pdf --output image-generated/${QMAKE_FILE_OUT_BASE}.pdf ${QMAKE_FILE_IN_BASE} ;
node_class_image.commands += $$VUORENDER --output-format=png --output image-generated/${QMAKE_FILE_OUT_BASE}.png ${QMAKE_FILE_IN_BASE} ;
QMAKE_EXTRA_COMPILERS += node_class_image

graph_image.input = GRAPH_IMAGES
graph_image.output = image-generated/${QMAKE_FILE_IN_BASE}.pdf
graph_image.commands  = $$VUORENDER --output-format=pdf --output image-generated/${QMAKE_FILE_OUT_BASE}.pdf ${QMAKE_FILE_IN} ;
graph_image.commands += $$VUORENDER --output-format=png --output image-generated/${QMAKE_FILE_OUT_BASE}.png ${QMAKE_FILE_IN} ;
QMAKE_EXTRA_COMPILERS += graph_image
