/**
 * @file
 * vuo.math.countWithinRange.integer node implementation.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#include "node.h"
#include <stdlib.h>

const char *moduleName = "Count Within Range";
const char *moduleDescription = "Keeps track of a count that starts at 0, and keeps the count within the range specified by `minimum` and `maximum`, either by saturating or wrapping (as specified by the `wrapMode` input). The count increases by `increment` when that port is pushed. It decreases by `decrement` when that port is pushed. When `refresh` is pushed, the count stays the same.";
const unsigned int moduleVersion = 100;
const bool nodeIsInterface = false;
const char *moduleKeywords[] = { "count", "range", "clamp", "loop", "iterate", "saturate", "wrap" };

VuoInteger * nodeInstanceInit()
{
	VuoInteger *countState = (VuoInteger *) malloc(sizeof(VuoInteger));
	vuoRegister(countState, free);
	*countState = 0;
	return countState;
}

void nodeInstanceEvent
(
		VuoInstanceData(VuoInteger *) countState,
		VuoInputData(VuoInteger, {"default":1}) increment,
		VuoInputConductor(VuoPortAlwaysConducts,increment) incrementEvent,
		VuoInputData(VuoInteger, {"default":1}) decrement,
		VuoInputConductor(VuoPortAlwaysConducts,decrement) decrementEvent,
		VuoOutputData(VuoInteger) count,
		VuoInputData(VuoInteger, {"default":0}) wrapMode,	// should be an enum w/ values for wrap and saturate
		VuoInputData(VuoInteger, {"default":0}) minimum,
		VuoInputData(VuoInteger, {"default":10}) maximum
)
{
	if(incrementEvent)
		**countState += increment;

	if(decrementEvent)
		**countState -= decrement;

	switch(wrapMode)
	{
		default:
		case 0:	// loop

			if(**countState > maximum)
				**countState = minimum;

			if(**countState < minimum)
				**countState = maximum;

			break;

		case 1: // saturate
			if(**countState > maximum)
				**countState = maximum;

			if(**countState < minimum)
				**countState = minimum;
			break;
	}

	*count = **countState;
}


void nodeInstanceFini(VuoInstanceData(VuoInteger *) countState)
{
}
